legacy_gantt_chart library
A Flutter package for displaying Gantt charts.
Classes
- CausalIntegrityAudit
- The Diagnostic Engine for inspecting the causal history of the Gantt system.
- ConflictAnalysis
- Represents the result of a conflict analysis between two operations.
- CpmTaskStats
- Holds calculated CPM statistics for a task.
- CRDTEngine
- The core engine for Conflict-Free Replicated Data Types (CRDT) logic.
- CriticalPathCalculator
- Utility class to perform Critical Path Method (CPM) analysis on a set of Gantt tasks.
- CriticalPathResult
- Result of a critical path calculation.
- GanttSyncClient
- Interface for the synchronization client. Users must implement this to provide their own backend.
- Hlc
- A Hybrid Logical Clock implementation.
- JiraStatusParser
- A utility class for parsing Jira "Time in Status" custom field strings.
- JiraStatusResult
- Represents the result of parsing a Jira "Time in Status" field.
- LegacyGanttChartColors
- Defines the color scheme for the Gantt chart.
- LegacyGanttChartWidget
- The main widget for displaying a Gantt chart.
- LegacyGanttConflictDetector
- A utility to detect and create indicators for conflicting tasks in a Gantt chart.
- LegacyGanttController
- A controller to programmatically manage a LegacyGanttChartWidget.
- LegacyGanttResource
- Represents a resource (person or job) in the Gantt chart.
- LegacyGanttRow
- Represents a row in the Gantt chart.
- LegacyGanttTask
- Represents a single task or event bar in the Gantt chart.
- LegacyGanttTaskDependency
- Represents a dependency relationship between two tasks in the Gantt chart.
- LegacyGanttTaskSegment
- Represents a single segment within a LegacyGanttTask.
- LegacyGanttTheme
- Defines the theme for the LegacyGanttChartWidget.
- LegacyGanttTimelineScrubber
- A widget that displays a timeline scrubber for a Gantt chart.
- LegacyGanttToolbar
- A toolbar that provides controls for the Gantt chart, such as switching between the Move and Select tools.
- LegacyGanttViewModel
- A ChangeNotifier that manages the state and interaction logic for the LegacyGanttChartWidget.
- MerkleNode
- Represents a node in the Merkle Tree.
- MerkleTree
- A time-based Merkle Tree implementation. It buckets items based on their last updated HLC timestamp.
- Operation
- Represents a single operation in the CRDT system.
- ProtocolDependency
- Represents a dependency relation between two tasks.
- ProtocolResource
- Represents a resource (person, equipment, etc.) in the Gantt project.
- ProtocolTag
- Represents an immutable snapshot (tag) of the project state.
- ProtocolTask
- Represents a task in the protocol layer (headless).
- RemoteCursor
- RemoteGhost
- SyncProgress
- Represents the progress of an inbound synchronization.
- SyncStats
- Statistics about the synchronization state.
- WebSocketGanttSyncClient
- WorkCalendar
- Defines the working schedule for the Gantt chart.
Enums
- DependencyType
- Defines the type of dependency between two tasks.
- DragMode
- GanttLoadingIndicatorPosition
- Defines the position for the linear progress indicator.
- GanttLoadingIndicatorType
- Defines the type of progress indicator to display during loading.
- GanttTool
- Defines the active tool for interacting with the Gantt chart.
- PanType
- ProtocolDependencyType
- Defines the type of dependency between two tasks.
- ResizePolicy
- Defines how a parent task resizing affects its children.
- ScrubberHandle
- Indicates which part of the scrubber was interacted with to cause a change.
- TaskPart
Typedefs
- CellBuilder = Widget Function(BuildContext context, DateTime date, double cellWidth, double cellHeight)
- Signature for a function that builds a widget for a timeline cell.